@@ -1,16 +1,13 @@
-# $Id: QNX.pm,v 1.1 2008/10/22 19:10:52 drhyde Exp $
+# $Id: QNX.pm,v 1.2 2008/10/27 20:31:21 drhyde Exp $
 
 package Devel::AssertOS::QNX;
 
 use Devel::CheckOS;
 
-$VERSION = '1.0';
-
-sub os_is {
-    Devel::CheckOS::os_is('QNX::v4') ||
-    Devel::CheckOS::os_is('QNX::Neutrino')
-}
+$VERSION = '1.1';
 
+sub matches { return qw(QNX::v4 QNX::Neutrino); }
+sub os_is { Devel::CheckOS::os_is(matches()); }
 Devel::CheckOS::die_unsupported() unless(os_is());
 
 =head1 COPYRIGHT and LICENCE
